import { Component, OnInit } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { TenantService } from '../data-object-service';
import { Tenant } from '../data-objects';
import { MessageService } from '../message.service';
import { Location } from '@angular/common'

@Component({
  selector: 'app-tenant-details',
  templateUrl: './tenant-details.component.html',
  styleUrls: ['./tenant-details.component.css']
})
export class TenantDetailsComponent implements OnInit {

  tenant: Tenant = {
    id: 0, 
    salutation: '', 
    firstname: '', 
    lastname: '', 
    address1: '', 
    address2: '', 
    address3: '', 
    zip: '', 
    city: '', 
    phone1: '', 
    phone2: '', 
    iban: '', 
    account: 0
  }


  constructor(
    private tenantService: TenantService, 
    private messageService: MessageService,
    private route: ActivatedRoute,
    private location: Location
  ) { }

  async getTenant(): Promise<void> {
    try {
      const id = +this.route.snapshot.paramMap.get('id')
      if (id != 0) {
        this.tenant = await this.tenantService.getTenant(id)
      }
    } catch (err) {
      this.messageService.add(JSON.stringify(err, undefined, 4))
    }
  }

  saveTenant() {
    this.messageService.add("saveTenant")
    this.messageService.add(JSON.stringify(this.tenant, undefined, 4))
    if (this.tenant.id == 0) {
      this.messageService.add("about to insert new tenant")
    } else {
      this.messageService.add("about to update existing tenant")
    }
  }

  ngOnInit(): void {
    this.getTenant()
  }

}
